@@ -6,7 +6,7 @@ use experimental 'smartmatch';
 
 # ABSTRACT: A Simple base module to implement almost every RESTful API with just a few lines of configuration
 
-our $VERSION = '2.5'; # VERSION
+our $VERSION = '2.6'; # VERSION
 
 use LWP::UserAgent;
 use HTTP::Cookies 6.04;
@@ -114,6 +114,13 @@ has 'auth_header' => (
 );
 
 
+has 'auth_header_token_format' => (
+    is      => 'rw',
+    isa     => 'Str',
+    default => sub { 'Token token=%s' },
+);
+
+
 has 'default_method' => (
     is      => 'rw',
     isa     => 'Str',
@@ -409,7 +416,6 @@ sub encode {
         }
         else {
             given ($content_type) {
-                when (/plain/) { $payload = $options; }
                 when (/urlencoded/) {
                     $payload .=
                         uri_escape($_) . '=' . uri_escape($options->{$_}) . '&'
@@ -418,6 +424,13 @@ sub encode {
                 }
                 when (/json/) { $payload = $self->json->encode($options); }
                 when (/xml/)  { $payload = $self->xml->XMLout($options); }
+                default {
+                    if (exists $options->{payload}
+                        and defined $options->{payload})
+                    {
+                        $payload = '' . $options->{payload};
+                    }
+                }
             }
         }
     };
@@ -439,7 +452,7 @@ sub talk {
         when ('basic') { $uri->userinfo($self->user . ':' . $self->api_key); }
         when ('header') {
             $self->header->{ $self->auth_header } =
-                "Token token=" . $self->api_key;
+                sprintf($self->auth_header_token_format, $self->api_key);
         }
         when ('hash_key') {
             my $api_key_field = $self->api_key_field;
@@ -941,7 +954,7 @@ Web::API - A Simple base module to implement almost every RESTful API with just
 
 =head1 VERSION
 
-version 2.5
+version 2.6
 
 =head1 SYNOPSIS
 
@@ -1155,6 +1168,12 @@ get/set the name of the header used for Authorization credentials
 
 default: Authorization
 
+=head2 auth_header_token_format
+
+get/set format of the auth_header token.
+
+default: 'Token token=%s'
+
 =head2 default_method (optional)
 
 get/set default HTTP method
